@@ -10,7 +10,6 @@ pub fn parser_options(options: &Options) -> String {
 // ParserOptions
 {parser_options_blob} {fn_attributes} {ns}__new(
     {string_ptr_blob} buffer_name_blob,
-    uint8_t debug,
     {maybe_decoder_blob} decoder_blob,
     {maybe_token_rewriter_blob} token_rewriter_blob,
     bool record_tokens);
@@ -22,7 +21,6 @@ extern \"C\" {{
 
 typedef struct InternalParserOptions {{
     {string_ptr_blob} buffer_name;
-    uint8_t debug;
     {maybe_decoder_blob} decoder;
     {maybe_token_rewriter_blob} token_rewriter;
     bool record_tokens;
@@ -34,7 +32,6 @@ typedef struct InternalParserOptions {{
 
 InternalParserOptions {fn_attributes} {ns}__into_internal({parser_options_blob} self_blob);
 const {string_ptr_blob} *{fn_attributes} {ns}__get_buffer_name(const {parser_options_blob} *self_blob);
-uint8_t {fn_attributes} {ns}__get_debug(const {parser_options_blob} *self_blob);
 const {maybe_decoder_blob} *{fn_attributes} {ns}__get_decoder(const {parser_options_blob} *self_blob);
 const {maybe_token_rewriter_blob} *{fn_attributes} {ns}__get_token_rewriter(const {parser_options_blob} *self_blob);
 bool {fn_attributes} {ns}__get_record_tokens(const {parser_options_blob} *self_blob);
