@@ -8,7 +8,7 @@ pub fn string_ptr(options: &Options) -> String {
     format!(
         "
 // StringPtr
-{string_ptr_blob} {fn_attributes} {ns}__new(const uint8_t *ptr, uint64_t len);
+{string_ptr_blob} {fn_attributes} {ns}__new(uint8_t *ptr, uint64_t len);
 void {fn_attributes} {ns}__drop({string_ptr_blob} *self_blob);
 const uint8_t *{fn_attributes} {ns}__as_raw(const {string_ptr_blob} *self_blob);
 uint8_t *{fn_attributes} {ns}__into_raw({string_ptr_blob} self_blob);
