@@ -40,9 +40,8 @@ pub fn generate(options: &Options) -> String {
 fn contents(options: &Options) -> String {
     vec![
         api::ptr(options),
-        api::maybe_ptr(options),
+        api::maybe(options),
         api::string_ptr(options),
-        api::maybe_string_ptr(options),
         api::shared_byte_list(options),
         api::list(options),
         api::source_line(options),
@@ -51,7 +50,6 @@ fn contents(options: &Options) -> String {
         api::comment_type(options),
         api::comment(options),
         api::loc(options),
-        api::maybe_loc(options),
         api::magic_comment_kind(options),
         api::magic_comment(options),
         api::error_level(options),
@@ -62,8 +60,6 @@ fn contents(options: &Options) -> String {
         api::decoder_result(options),
         api::decoder(options),
         api::token_rewriter(options),
-        api::maybe_decoder(options),
-        api::maybe_token_rewriter(options),
         api::parser_options(options),
         api::decoded_input(options),
         api::parser_result(options),
